@@ -1,4 +1,4 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl -X
 package AI::MicroStructure::Relations;
 use strict;
 use warnings;
@@ -9,7 +9,7 @@ use WWW::Wikipedia;
 use JSON::XS;
 use Statistics::Basic qw(:all);
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 our $supports = {};
 our $scale = 1;
 
@@ -36,7 +36,8 @@ my   $result = $wiki->search($next);
 
 
     	eval( 'use IO::Page' );
-      if($result){
+
+      if(defined($result) and $result){
 
         use AnyEvent::Subprocess::Easy qw(qx_nonblock);
         my $micosense = qx_nonblock("micro-sense $next")->recv;
@@ -56,8 +57,8 @@ my   $result = $wiki->search($next);
          $self->{storage}->{data}->{$elem}+1:1; 
 
 
-         if($_ &&
-           !defined($self->{storage}->{data}->{$elem})) {
+#         if($_ &&
+ #          !defined($self->{storage}->{data}->{$elem})) {
 
           # $wiki = WWW::Wikipedia->new();
           # $result = $wiki->search($_);
@@ -69,7 +70,7 @@ my   $result = $wiki->search($next);
 
          #  $self->{storage}->{$_}->{related} = [grep{!/\(/}map{$_=~ s/ /_/g; $_=ucfirst $_;}$result->related()] unless(!$result);
 
-         }
+  #       }
 
 
 
@@ -120,7 +121,7 @@ sub inspect {
   
   ~$ micro new world
   
-  ~$ micro themes
+  ~$ micro structures
   
   ~$ micro any 2
   
